==> flutter_country_state-0.0.21.tar.gz: lib/cty-list.dart <==
///list of countries .sepreted because it will be merge in the init state for fast loading

class Country1 {
  static List<String> Countrys1 = <String>[
    "Afghanistan", "Aland Islands", "Albania", "Algeria", "American Samoa", "Andorra",
    "Angola", "Anguilla", "Antarctica", "Antigua", "Argentina", "Armenia", "Aruba",
    "Australia", "Austria", "Azerbaijan", "Bahamas", "Bahrain", "Bangladesh","Arab",
    "Barbados", "Barbuda", "Belarus", "Belgium", "Belize", "Benin", "Bermuda",
    "Bhutan", "Bolivia", "Bosnia", "Botswana", "Bouvet Island", "Brazil", "British",

  ];
}


class Country2{
  static List<String> country2 = <String>[
    "Brunei", "Bulgaria", "Burkina Faso", "Burundi", "Caicos Islands", "Cambodia", "Cameroon", "Canada", "Cape Verde",
    "Cayman Islands", "Central African Republic", "Chad", "Chile", "China",
    "Colombia", "Comoros", "Congo", "Costa Rica", "Cote d'Ivoire", "Croatia", "Cuba", "Cyprus", "Czech Republic", "Denmark",
    "Djibouti", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador",
    "Equatorial Guinea", "Eritrea", "Estonia", "Ethiopia", "Faroe Islands", "Fiji", "Finland", "France",

  ];
}

class Country3{
  static List<String> country3 = <String>[

    "French Guiana", "French Polynesia", "French Southern", "Gabon", "Gambia", "Germany", "Ghana", "Gibraltar",
    "Greece", "Greenland", "Grenada", "Guadeloupe", "Guam", "Guatemala", "Guernsey",
    "Guinea", "Guinea-Bissau", "Guyana", "Haiti", "Heard", "Herzegovina",
    "Holy See", "Honduras", "Hong Kong", "Hungary", "Iceland", "India", "Indonesia",
    "Iran", "Iraq", "Ireland", "Isle", "Israel", "Italy", "Jamaica", "Japan", "Jersey", "Jordan",

  ];
}

class Country4{
  static List<String> country4 = <String>[
    "Kazakhstan", "Kenya", "Kiribati", "South Korea", "North Korea","Kuwait",
    "Kyrgyzstan", "Laos", "Latvia", "Lebanon", "Lesotho", "Liberia", "Liechtenstein", "Lithuania", "Luxembourg",
    "Macao", "Macedonia", "Madagascar", "Malawi", "Malaysia", "Maldives",
    "Mali", "Malta", "Marshall Islands", "Martinique", "Mauritania", "Mauritius",
    "Mayotte", "McDonald Islands", "Mexico", "Micronesia", "Miquelon", "Moldova",

  ];
}

class Country5{
  static List<String> country5 = <String>[
    "Monaco", "Mongolia", "Montenegro", "Montserrat", "Morocco", "Mozambique",
    "Myanmar", "Namibia", "Nauru", "Nepal", "Netherlands", "Netherlands Antilles",
    "Nevis", "New Caledonia", "New Zealand", "Nicaragua", "Niger", "Nigeria",
    "Northern Mariana Islands", "Norway", "Oman", "Pakistan", "Palau", "Palestinian", "Panama", "Papua New Guinea",
    "Paraguay", "Peru", "Philippines", "Pitcairn", "Poland", "Portugal", "Principe",

  ];
}

class Country6{
  static List<String> country6 = <String>[
    "Puerto Rico", "Qatar", "Romania", "Russia", "Rwanda", "Saint Helena", "Saint Kitts", "Saint Lucia",
    "Saint Pierre", "Saint Vincent", "Samoa", "San Marino", "Sao Tome", "Saudi Arabia", "Senegal", "Serbia", "Seychelles",
    "Sierra Leone", "Singapore", "Slovakia", "Slovenia", "Solomon Islands", "Somalia", "South Africa", "Spain",
    "Sri Lanka", "Sudan", "Suriname", "Svalbard", "Swaziland", "Sweden", "Switzerland", "Syria", "Taiwan", "Tajikistan", "Tanzania",
    "Thailand", "Tobago", "Togo", "Tokelau", "Tonga", "Trinidad", "Tunisia", "Turkey", "Turkmenistan", "Turks Islands",

  ];
}

class Country7{
  static List<String> country7 = <String>[
    "Tuvalu", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "USA", "Uruguay", "US Minor Outlying Islands", "Uzbekistan",
    "Vanuatu", "Vatican City State", "Venezuela", "Vietnam", "Wallis",
    "Yemen", "Zambia", "Zimbabwe"
  ];
}

==> flutter_country_state-0.2.4.tar.gz: lib/cty-list.dart <==
///list of countries .sepreted because it will be merge in the init state for fast loading

class Country1 {
  static List<String> Countrys1 = <String>[
    "Afghanistan", "Aland Islands", "Albania", "Algeria", "American Samoa", "Andorra",
    "Angola", "Anguilla", "Antarctica", "Antigua", "Argentina", "Armenia", "Aruba",
    "Australia", "Austria", "Azerbaijan", "Bahamas", "Bahrain", "Bangladesh","Arab",
    "Barbados", "Barbuda", "Belarus", "Belgium", "Belize", "Benin", "Bermuda",
    "Bhutan", "Bolivia", "Bosnia", "Botswana", "Bouvet Island", "Brazil", "British",

  ];
}


class Country2{
  static List<String> country2 = <String>[
    "Brunei", "Bulgaria", "Burkina Faso", "Burundi", "Caicos Islands", "Cambodia", "Cameroon", "Canada", "Cape Verde",
    "Cayman Islands", "Central African Republic", "Chad", "Chile", "China",
    "Colombia", "Comoros", "Congo", "Costa Rica", "Cote d'Ivoire", "Croatia", "Cuba", "Cyprus", "Czech Republic", "Denmark",
    "Djibouti", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador",
    "Equatorial Guinea", "Eritrea", "Estonia", "Ethiopia", "Faroe Islands", "Fiji", "Finland", "France",

  ];
}

class Country3{
  static List<String> country3 = <String>[

    "French Guiana", "French Polynesia", "French Southern", "Gabon", "Gambia", "Germany", "Ghana", "Gibraltar",
    "Greece", "Greenland", "Grenada", "Guadeloupe", "Guam", "Guatemala", "Guernsey",
    "Guinea", "Guinea-Bissau", "Guyana", "Haiti", "Heard", "Herzegovina",
    "Holy See", "Honduras", "Hong Kong", "Hungary", "Iceland", "India", "Indonesia",
    "Iran", "Iraq", "Ireland", "Isle", "Israel", "Italy", "Jamaica", "Japan", "Jersey", "Jordan",

  ];
}

class Country4{
  static List<String> country4 = <String>[
    "Kazakhstan", "Kenya", "Kiribati", "South Korea", "North Korea","Kuwait",
    "Kyrgyzstan", "Laos", "Latvia", "Lebanon", "Lesotho", "Liberia", "Liechtenstein", "Lithuania", "Luxembourg",
    "Macao", "Macedonia", "Madagascar", "Malawi", "Malaysia", "Maldives",
    "Mali", "Malta", "Marshall Islands", "Martinique", "Mauritania", "Mauritius",
    "Mayotte", "McDonald Islands", "Mexico", "Micronesia", "Miquelon", "Moldova",

  ];
}

class Country5{
  static List<String> country5 = <String>[
    "Monaco", "Mongolia", "Montenegro", "Montserrat", "Morocco", "Mozambique",
    "Myanmar", "Namibia", "Nauru", "Nepal", "Netherlands", "Netherlands Antilles",
    "Nevis", "New Caledonia", "New Zealand", "Nicaragua", "Niger", "Nigeria",
    "Northern Mariana Islands", "Norway", "Oman", "Pakistan", "Palau", "Palestinian", "Panama", "Papua New Guinea",
    "Paraguay", "Peru", "Philippines", "Pitcairn", "Poland", "Portugal", "Principe",

  ];
}

class Country6{
  static List<String> country6 = <String>[
    "Puerto Rico", "Qatar", "Romania", "Russia", "Rwanda", "Saint Helena", "Saint Kitts", "Saint Lucia",
    "Saint Pierre", "Saint Vincent", "Samoa", "San Marino", "Sao Tome", "Saudi Arabia", "Senegal", "Serbia", "Seychelles",
    "Sierra Leone", "Singapore", "Slovakia", "Slovenia", "Solomon Islands", "Somalia", "South Africa", "Spain",
    "Sri Lanka", "Sudan", "Suriname", "Svalbard", "Swaziland", "Sweden", "Switzerland", "Syria", "Taiwan", "Tajikistan", "Tanzania",
    "Thailand", "Tobago", "Togo", "Tokelau", "Tonga", "Trinidad", "Tunisia", "Turkey", "Turkmenistan", "Turks Islands",

  ];
}

class Country7{
  static List<String> country7 = <String>[
    "Tuvalu", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "United States of America", "Uruguay", "US Minor Outlying Islands", "Uzbekistan",
    "Vanuatu", "Vatican City State", "Venezuela", "Vietnam", "Wallis",
    "Yemen", "Zambia", "Zimbabwe"
  ];
}
